@@ -50,7 +50,7 @@ def get_helper(
         database=database,
         schema_name=schema_name,
         driver="postgresql+psycopg2",
-        series_schema='series'
+        series_schema="series",
     )
 
 
