@@ -9,6 +9,7 @@ from functools import lru_cache
 
 import boto3
 import click
+import sqlalchemy.types as types
 from sqlalchemy import PrimaryKeyConstraint
 from sqlalchemy import (
     Table,
@@ -19,7 +20,6 @@ from sqlalchemy import (
     BigInteger,
     Index,
 )
-import sqlalchemy.types as types
 from sqlalchemy.dialects import postgresql
 from sqlalchemy.dialects.postgresql.base import BYTEA
 from sqlalchemy.schema import CreateTable
@@ -163,26 +163,8 @@ class RedshiftProvider(MigrationProvider):
         primary_key_columns: typing.List[str],
         **kwargs,
     ) -> Table:
-        dist_key_columns = ["knowledge_hash"]
-
-        dist_columns = list(filter(lambda x: "identity" in x.name, columns))
-        if len(dist_columns) > 0:
-            dist_key_columns = dist_columns
-
         return super(RedshiftProvider, self).create_table(
-            name,
-            schema,
-            columns,
-            primary_key_columns,
-            redshift_distkey=dist_key_columns[0],
-            redshift_sortkey=[
-                "effective_start_dt",
-                "effective_end_dt",
-                "knowledge_start_dt",
-                "knowledge_end_dt",
-                "valid_start_dt",
-                "valid_end_dt",
-            ],
+            name, schema, columns, primary_key_columns
         )
 
     def supports_indices(self):
